==> iaxmodem-0.1.9.tar.gz: iaxmodem-0.1.9/lib/spandsp/tests/regression_tests.sh <==
#!/bin/bash
#
# spandsp regression tests
#
# $Id: regression_tests.sh,v 1.14 2006/05/08 13:22:57 steveu Exp $
#

./adsi_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo adsi_tests failed!
    exit
fi
echo adsi_tests complete

./alaw_ulaw_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo alaw_ulaw_tests failed!
    exit
fi
echo alaw_ulaw_tests complete

./async_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo async_tests failed!
    exit
fi
echo async_tests complete

./at_interpreter_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo at_interpreter_tests failed!
    exit
fi
echo at_interpreter_tests complete

./awgn_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo awgn_tests failed!
    exit
fi
echo awgn_tests complete

./bell_mf_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo bell_mf_tests failed!
    exit
fi
echo bell_mf_tests complete

./bert_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo bert_tests failed!
    exit
fi
echo bert_tests complete

./bit_operations_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo bit_operations_tests failed!
    exit
fi
echo bit_operations_tests complete

./dc_restore_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo dc_restore_tests failed!
    exit
fi
echo dc_restore_tests complete

./dds_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo dds_tests failed!
    exit
fi
echo dds_tests complete

./dtmf_rx_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo dtmf_rx_tests failed!
    exit
fi
echo dtmf_rx_tests complete

./dtmf_tx_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo dtmf_tx_tests failed!
    exit
fi
echo dtmf_tx_tests complete

./ec_disable_tone_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo ec_disable_tone_tests failed!
    exit
fi
echo ec_disable_tone_tests complete

#./echo_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo echo_tests failed!
#    exit
#fi
#echo echo_tests complete

./fax_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo fax_tests failed!
    exit
fi
# Now use tiffcmp to check the results. It will return non-zero if any page images differ. The -t
# option means the normal differences in tags will be ignored.
tiffcmp -t itutests.tif fax_tests_1.tif >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo fax_tests failed!
    exit
fi
echo fax_tests complete

./fsk_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo fsk_tests failed!
    exit
fi
echo fsk_tests complete

./g722_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo g722_tests failed!
    exit
fi
echo g722_tests complete

./g726_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo g726_tests failed!
    exit
fi
echo g726_tests complete

./hdlc_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo hdlc_tests failed!
    exit
fi
echo hdlc_tests complete

./ima_adpcm_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo ima_adpcm_tests failed!
    exit
fi
echo ima_adpcm_tests complete

./modem_echo_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo modem_echo_tests failed!
    exit
fi
echo modem_echo_tests complete

./noise_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo noise_tests failed!
    exit
fi
echo noise_tests complete

./oki_adpcm_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo oki_adpcm_tests failed!
    exit
fi
echo oki_adpcm_tests complete

#./playout_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo playout_tests failed!
#    exit
#fi
#echo playout_tests complete

#./plc_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo plc_tests failed!
#    exit
#fi
#echo plc_tests complete

./power_meter_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo power_meter_tests failed!
    exit
fi
echo power_meter_tests complete

./r2_mf_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo r2_mf_tests failed!
    exit
fi
echo r2_mf_tests complete

./schedule_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo schedule_tests failed!
    exit
fi
echo schedule_tests complete

#./sig_tone_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo sig_tone_tests failed!
#    exit
#fi
#echo sig_tone_tests complete

#./super_tone_rx_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo super_tone_rx_tests failed!
#    exit
#fi
#echo super_tone_rx_tests complete

#./super_tone_tx_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo super_tone_tx_tests failed!
#    exit
#fi
#echo super_tone_tx_tests complete

#./t31_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo t31_tests failed!
#    exit
#fi
#echo t31_tests complete

./t38_gateway_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_gateway_tests failed!
    exit
fi
# Now use tiffcmp to check the results. It will return non-zero if any page images differ. The -t
# option means the normal differences in tags will be ignored.
tiffcmp -t itutests.tif t38.tif >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_gateway_tests failed!
    exit
fi
echo t38_gateway_tests complete

./t38_gateway_to_terminal_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_gateway_to_terminal_tests failed!
    exit
fi
# Now use tiffcmp to check the results. It will return non-zero if any page images differ. The -t
# option means the normal differences in tags will be ignored.
tiffcmp -t itutests.tif t38.tif >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_gateway_to_terminal_tests failed!
    exit
fi
echo t38_gateway_to_terminal_tests complete

./t38_terminal_to_gateway_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_terminal_to_gateway_tests failed!
    exit
fi
# Now use tiffcmp to check the results. It will return non-zero if any page images differ. The -t
# option means the normal differences in tags will be ignored.
tiffcmp -t itutests.tif t38.tif >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_terminal_to_gateway_tests failed!
    exit
fi
echo t38_terminal_to_gateway_tests complete

./t38_terminal_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_terminal_tests failed!
    exit
fi
# Now use tiffcmp to check the results. It will return non-zero if any page images differ. The -t
# option means the normal differences in tags will be ignored.
tiffcmp -t itutests.tif t38.tif >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_terminal_tests failed!
    exit
fi
echo t38_terminal_tests complete

./t4_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t4_tests failed!
    exit
fi
# Now use tiffcmp to check the results. It will return non-zero if any page images differ. The -t
# option means the normal differences in tags will be ignored.
tiffcmp -t itutests.tif t4_tests_receive.tif >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t4_tests failed!
    exit
fi
echo t4_tests complete

#./time_scale_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo time_scale_tests failed!
#    exit
#fi
#echo time_scale_tests complete

#./tone_generate_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo tone_generate_tests failed!
#    exit
#fi
#echo tone_generate_tests complete

#./v17_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo v17_tests failed!
#    exit
#fi
#echo v17_tests complete

#./v22bis_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo v22bis_tests failed!
#    exit
#fi
#echo v22bis_tests complete

./v27ter_tests -s -36 2400 >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v27ter_tests failed!
    exit
fi
./v27ter_tests -s -36 4800 >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v27ter_tests failed!
    exit
fi
echo v27ter_tests complete

./v29_tests -s -38 4800 >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v29_tests failed!
    exit
fi
./v29_tests -s -38 7200 >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v29_tests failed!
    exit
fi
./v29_tests -s -38 9600 >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v29_tests failed!
    exit
fi
echo v29_tests complete

#./v42_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo v42_tests failed!
#    exit
#fi
#echo v42_tests complete

./v42bis_tests.sh >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v42bis_tests failed!
    exit
fi
echo v42bis_tests complete

./v8_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v8_tests failed!
    exit
fi
echo v8_tests complete

==> iaxmodem-0.1.14.tar.gz: iaxmodem-0.1.14/lib/spandsp/tests/regression_tests.sh <==
#!/bin/bash
#
# spandsp regression tests
#
# $Id: regression_tests.sh,v 1.18 2006/06/27 13:25:30 steveu Exp $
#

ITUTESTS_TIF=../itutests/fax/itutests.tif

echo Performing basic regression tests
echo

./adsi_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo adsi_tests failed!
    exit $RETVAL
fi
echo adsi_tests completed OK

./async_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo async_tests failed!
    exit $RETVAL
fi
echo async_tests completed OK

./at_interpreter_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo at_interpreter_tests failed!
    exit $RETVAL
fi
echo at_interpreter_tests completed OK

./awgn_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo awgn_tests failed!
    exit $RETVAL
fi
echo awgn_tests completed OK

./bell_mf_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo bell_mf_tests failed!
    exit $RETVAL
fi
echo bell_mf_tests completed OK

./bert_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo bert_tests failed!
    exit $RETVAL
fi
echo bert_tests completed OK

./bit_operations_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo bit_operations_tests failed!
    exit $RETVAL
fi
echo bit_operations_tests completed OK

./dc_restore_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo dc_restore_tests failed!
    exit $RETVAL
fi
echo dc_restore_tests completed OK

./dds_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo dds_tests failed!
    exit $RETVAL
fi
echo dds_tests completed OK

./dtmf_rx_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo dtmf_rx_tests failed!
    exit $RETVAL
fi
echo dtmf_rx_tests completed OK

./dtmf_tx_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo dtmf_tx_tests failed!
    exit $RETVAL
fi
echo dtmf_tx_tests completed OK

./ec_disable_tone_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo ec_disable_tone_tests failed!
    exit $RETVAL
fi
echo ec_disable_tone_tests completed OK

#./echo_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo echo_tests failed!
#    exit $RETVAL
#fi
#echo echo_tests completed OK
echo echo_tests not enabled

./fax_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo fax_tests failed!
    exit $RETVAL
fi
# Now use tiffcmp to check the results. It will return non-zero if any page images differ. The -t
# option means the normal differences in tags will be ignored.
tiffcmp -t ${ITUTESTS_TIF} fax_tests_1.tif >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo fax_tests failed!
    exit $RETVAL
fi
echo fax_tests completed OK

./fsk_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo fsk_tests failed!
    exit $RETVAL
fi
echo fsk_tests completed OK

./g711_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo g711_tests failed!
    exit $RETVAL
fi
echo g711_tests completed OK

./g722_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo g722_tests failed!
    exit $RETVAL
fi
echo g722_tests completed OK

./g726_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo g726_tests failed!
    exit $RETVAL
fi
echo g726_tests completed OK

./gsm0610_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo gsm0610_tests failed!
    exit $RETVAL
fi
echo gsm0610_tests completed OK

./hdlc_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo hdlc_tests failed!
    exit $RETVAL
fi
echo hdlc_tests completed OK

./ima_adpcm_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo ima_adpcm_tests failed!
    exit $RETVAL
fi
echo ima_adpcm_tests completed OK

./modem_echo_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo modem_echo_tests failed!
    exit $RETVAL
fi
echo modem_echo_tests completed OK

./noise_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo noise_tests failed!
    exit $RETVAL
fi
echo noise_tests completed OK

./oki_adpcm_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo oki_adpcm_tests failed!
    exit $RETVAL
fi
echo oki_adpcm_tests completed OK

#./playout_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo playout_tests failed!
#    exit $RETVAL
#fi
#echo playout_tests completed OK
echo playout_tests not enabled

#./plc_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo plc_tests failed!
#    exit $RETVAL
#fi
#echo plc_tests completed OK
echo plc_tests not enabled

./power_meter_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo power_meter_tests failed!
    exit $RETVAL
fi
echo power_meter_tests completed OK

./r2_mf_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo r2_mf_tests failed!
    exit $RETVAL
fi
echo r2_mf_tests completed OK

./schedule_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo schedule_tests failed!
    exit $RETVAL
fi
echo schedule_tests completed OK

#./sig_tone_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo sig_tone_tests failed!
#    exit $RETVAL
#fi
#echo sig_tone_tests completed OK
echo sig_tone_tests not enabled

#./super_tone_rx_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo super_tone_rx_tests failed!
#    exit $RETVAL
#fi
#echo super_tone_rx_tests completed OK
echo super_tone_rx_tests not enabled

#./super_tone_tx_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo super_tone_tx_tests failed!
#    exit $RETVAL
#fi
#echo super_tone_tx_tests completed OK
echo super_tone_tx_tests not enabled

#./t31_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo t31_tests failed!
#    exit $RETVAL
#fi
#echo t31_tests completed OK
echo t31_tests not enabled

./t38_gateway_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_gateway_tests failed!
    exit $RETVAL
fi
# Now use tiffcmp to check the results. It will return non-zero if any page images differ. The -t
# option means the normal differences in tags will be ignored.
tiffcmp -t ${ITUTESTS_TIF} t38.tif >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_gateway_tests failed!
    exit $RETVAL
fi
echo t38_gateway_tests completed OK

./t38_gateway_to_terminal_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_gateway_to_terminal_tests failed!
    exit $RETVAL
fi
# Now use tiffcmp to check the results. It will return non-zero if any page images differ. The -t
# option means the normal differences in tags will be ignored.
tiffcmp -t ${ITUTESTS_TIF} t38.tif >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_gateway_to_terminal_tests failed!
    exit $RETVAL
fi
echo t38_gateway_to_terminal_tests completed OK

./t38_terminal_to_gateway_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_terminal_to_gateway_tests failed!
    exit $RETVAL
fi
# Now use tiffcmp to check the results. It will return non-zero if any page images differ. The -t
# option means the normal differences in tags will be ignored.
tiffcmp -t ${ITUTESTS_TIF} t38.tif >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_terminal_to_gateway_tests failed!
    exit $RETVAL
fi
echo t38_terminal_to_gateway_tests completed OK

./t38_terminal_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_terminal_tests failed!
    exit $RETVAL
fi
# Now use tiffcmp to check the results. It will return non-zero if any page images differ. The -t
# option means the normal differences in tags will be ignored.
tiffcmp -t ${ITUTESTS_TIF} t38.tif >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t38_terminal_tests failed!
    exit $RETVAL
fi
echo t38_terminal_tests completed OK

./t4_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t4_tests failed!
    exit $RETVAL
fi
# Now use tiffcmp to check the results. It will return non-zero if any page images differ. The -t
# option means the normal differences in tags will be ignored.
tiffcmp -t ${ITUTESTS_TIF} t4_tests_receive.tif >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo t4_tests failed!
    exit $RETVAL
fi
echo t4_tests completed OK

#./time_scale_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo time_scale_tests failed!
#    exit $RETVAL
#fi
#echo time_scale_tests completed OK
echo time_scale_tests not enabled

#./tone_generate_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo tone_generate_tests failed!
#    exit $RETVAL
#fi
#echo tone_generate_tests completed OK
echo tone_generate_tests not enabled

#./v17_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo v17_tests failed!
#    exit $RETVAL
#fi
#echo v17_tests completed OK
echo v17_tests not enabled

#./v22bis_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo v22bis_tests failed!
#    exit $RETVAL
#fi
#echo v22bis_tests completed OK
echo v22bis_tests not enabled

./v27ter_tests -s -36 2400 >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v27ter_tests failed!
    exit $RETVAL
fi
./v27ter_tests -s -36 4800 >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v27ter_tests failed!
    exit $RETVAL
fi
echo v27ter_tests completed OK

./v29_tests -s -38 4800 >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v29_tests failed!
    exit $RETVAL
fi
./v29_tests -s -38 7200 >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v29_tests failed!
    exit $RETVAL
fi
./v29_tests -s -38 9600 >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v29_tests failed!
    exit $RETVAL
fi
echo v29_tests completed OK

#./v42_tests >xyzzy 2>xyzzy2
#RETVAL=$?
#if [ $RETVAL != 0 ]
#then
#    echo v42_tests failed!
#    exit $RETVAL
#fi
#echo v42_tests completed OK
echo v42_tests not enabled

./v42bis_tests.sh >/dev/null
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v42bis_tests failed!
    exit $RETVAL
fi
echo v42bis_tests completed OK

./v8_tests >xyzzy 2>xyzzy2
RETVAL=$?
if [ $RETVAL != 0 ]
then
    echo v8_tests failed!
    exit $RETVAL
fi
echo v8_tests completed OK

echo
echo All regression tests successfully completed
